C-- HMS_asym
C-- beamE = (MeV) Energy of incident beam
C-- HMS_mom = (MeV) Central momentum of HMS
C-- HMS_angle = (degree) Angle between HMS and outgoing beam

      real function HMS_asym(beamE,HMS_mom,HMS_angle)

      include ?
      
      real beamE,HMS_mom,HMS_angle
      real x_bj,Q_sq,W_sq,nu
      real E_e

      if(bgtype.EQ.1.AND.abs(hms_delta).LT.8.0) then
         E_e=HMS_mom*(1.+hms_delta/100.)
         call Invariants_ep(beamE,E_e,
     &                      HMS_angle,x_bj,Q_sq,W_sq,nu)
C-- 100 sigma(parallel) + sigma(anti-parallel) (old)
C-- 101 sigma(parallel) - sigma(anti-parallel) (old)
         call HF1(1,Q_sq/1000000.,1.)
         call HF1(2,sqrt(W_sq)/1000.,1.)
         call HF1(3,x_bj,1.)
         call HF1(4,E_e/1000.,1.)
         if(i_helicity.EQ.1.) then
            call HF1(100,x_bj,1.)
            call HF1(200,sqrt(W_sq)/1000.,1.)
         endif
         if(i_helicity.EQ.-1.) then
            call HF1(101,x_bj,1.)
            call HF1(201,sqrt(W_sq)/1000.,1.)
         endif
      endif

      end

C-- Invariants_ep(in,in,in,out,out,out,out)
C-- E_i = (MeV) Initial electron energy
C-- E_f = (MeV) Final electron energy
C-- theta = (degree) Electron's scattering angle with respect
C--          to the electron beam direction
C-- x_bj = (dim'less) Bjorken x
C-- Q_sq = (MeV^2) Q^2 = -q^2 where q is 4-mom. transfered
C-- W_sq = (MeV^2) W^2 = (P+q)^2 where P is the 4-mom. of nucleon
C-- nu = (MeV) electron's energy loss in the nucleon rest frame
 
      subroutine Invariants_ep(E_i,E_f,theta,x_bj,Q_sq,W_sq,nu)

      real E_i,E_f,theta
      real x_bj,Q_sq,W_sq,nu
      parameter (M = 938.272 )
      parameter (d2r = 3.14159/180.)

      Q_sq = 4*E_i*E_f*(SIN(theta*d2r/2))**2
      nu = E_i - E_f
      x_bj = Q_sq/(2*M*nu)
      W_sq = M**2 + 2*M*nu - Q_sq

      end
